"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: f582b26db67b

from __future__ import annotations
from .audiourl import AudioURL, AudioURLTypedDict
from mistralai.client.types import BaseModel
from mistralai.client.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal, Union
from typing_extensions import Annotated, TypeAliasType, TypedDict


AudioURLUnionTypedDict = TypeAliasType(
    "AudioURLUnionTypedDict", Union[AudioURLTypedDict, str]
)


AudioURLUnion = TypeAliasType("AudioURLUnion", Union[AudioURL, str])


class AudioURLChunkTypedDict(TypedDict):
    r"""Audio URL chunk.

    Attributes:
    type: The type of the chunk, which is always `ChunkTypes.audio_url`.
    audio_url: The URL of the audio file.
    """

    audio_url: AudioURLUnionTypedDict
    type: Literal["audio_url"]


class AudioURLChunk(BaseModel):
    r"""Audio URL chunk.

    Attributes:
    type: The type of the chunk, which is always `ChunkTypes.audio_url`.
    audio_url: The URL of the audio file.
    """

    audio_url: AudioURLUnion

    type: Annotated[
        Annotated[Literal["audio_url"], AfterValidator(validate_const("audio_url"))],
        pydantic.Field(alias="type"),
    ] = "audio_url"


try:
    AudioURLChunk.model_rebuild()
except NameError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 58d633507527

from __future__ import annotations
from .codeinterpretertool import CodeInterpreterTool, CodeInterpreterToolTypedDict
from .completionargs import CompletionArgs, CompletionArgsTypedDict
from .conversationinputs import ConversationInputs, ConversationInputsTypedDict
from .documentlibrarytool import DocumentLibraryTool, DocumentLibraryToolTypedDict
from .functiontool import FunctionTool, FunctionToolTypedDict
from .guardrailconfig import GuardrailConfig, GuardrailConfigTypedDict
from .imagegenerationtool import ImageGenerationTool, ImageGenerationToolTypedDict
from .websearchpremiumtool import WebSearchPremiumTool, WebSearchPremiumToolTypedDict
from .websearchtool import WebSearchTool, WebSearchToolTypedDict
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import Field, model_serializer
from typing import Any, Dict, List, Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


ConversationStreamRequestHandoffExecution = Literal[
    "client",
    "server",
]


ConversationStreamRequestToolTypedDict = TypeAliasType(
    "ConversationStreamRequestToolTypedDict",
    Union[
        FunctionToolTypedDict,
        WebSearchToolTypedDict,
        WebSearchPremiumToolTypedDict,
        CodeInterpreterToolTypedDict,
        ImageGenerationToolTypedDict,
        DocumentLibraryToolTypedDict,
    ],
)


ConversationStreamRequestTool = Annotated[
    Union[
        CodeInterpreterTool,
        DocumentLibraryTool,
        FunctionTool,
        ImageGenerationTool,
        WebSearchTool,
        WebSearchPremiumTool,
    ],
    Field(discriminator="type"),
]


ConversationStreamRequestAgentVersionTypedDict = TypeAliasType(
    "ConversationStreamRequestAgentVersionTypedDict", Union[str, int]
)


ConversationStreamRequestAgentVersion = TypeAliasType(
    "ConversationStreamRequestAgentVersion", Union[str, int]
)


class ConversationStreamRequestTypedDict(TypedDict):
    inputs: ConversationInputsTypedDict
    stream: NotRequired[bool]
    store: NotRequired[Nullable[bool]]
    handoff_execution: NotRequired[Nullable[ConversationStreamRequestHandoffExecution]]
    instructions: NotRequired[Nullable[str]]
    tools: NotRequired[List[ConversationStreamRequestToolTypedDict]]
    r"""List of tools which are available to the model during the conversation."""
    completion_args: NotRequired[Nullable[CompletionArgsTypedDict]]
    guardrails: NotRequired[Nullable[List[GuardrailConfigTypedDict]]]
    name: NotRequired[Nullable[str]]
    description: NotRequired[Nullable[str]]
    metadata: NotRequired[Nullable[Dict[str, Any]]]
    agent_id: NotRequired[Nullable[str]]
    agent_version: NotRequired[Nullable[ConversationStreamRequestAgentVersionTypedDict]]
    model: NotRequired[Nullable[str]]


class ConversationStreamRequest(BaseModel):
    inputs: ConversationInputs

    stream: Optional[bool] = True

    store: OptionalNullable[bool] = UNSET

    handoff_execution: OptionalNullable[ConversationStreamRequestHandoffExecution] = (
        UNSET
    )

    instructions: OptionalNullable[str] = UNSET

    tools: Optional[List[ConversationStreamRequestTool]] = None
    r"""List of tools which are available to the model during the conversation."""

    completion_args: OptionalNullable[CompletionArgs] = UNSET

    guardrails: OptionalNullable[List[GuardrailConfig]] = UNSET

    name: OptionalNullable[str] = UNSET

    description: OptionalNullable[str] = UNSET

    metadata: OptionalNullable[Dict[str, Any]] = UNSET

    agent_id: OptionalNullable[str] = UNSET

    agent_version: OptionalNullable[ConversationStreamRequestAgentVersion] = UNSET

    model: OptionalNullable[str] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "stream",
                "store",
                "handoff_execution",
                "instructions",
                "tools",
                "completion_args",
                "guardrails",
                "name",
                "description",
                "metadata",
                "agent_id",
                "agent_version",
                "model",
            ]
        )
        nullable_fields = set(
            [
                "store",
                "handoff_execution",
                "instructions",
                "completion_args",
                "guardrails",
                "name",
                "description",
                "metadata",
                "agent_id",
                "agent_version",
                "model",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: ef9914284afb

from __future__ import annotations
from mistralai.client.types import BaseModel
from mistralai.client.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class AgentsAPIV1AgentsGetVersionRequestTypedDict(TypedDict):
    agent_id: str
    version: str


class AgentsAPIV1AgentsGetVersionRequest(BaseModel):
    agent_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    version: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mistralai.gcp.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
import pydantic
from pydantic import model_serializer
from typing import Any, Dict, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class JSONSchemaTypedDict(TypedDict):
    name: str
    schema_definition: Dict[str, Any]
    description: NotRequired[Nullable[str]]
    strict: NotRequired[bool]


class JSONSchema(BaseModel):
    name: str

    schema_definition: Annotated[Dict[str, Any], pydantic.Field(alias="schema")]

    description: OptionalNullable[str] = UNSET

    strict: Optional[bool] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["description", "strict"])
        nullable_fields = set(["description"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


try:
    JSONSchema.model_rebuild()
except NameError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 853a43ee6b98

from __future__ import annotations
from mistralai.client.types import BaseModel
from mistralai.client.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class GetCampaignStatusByIDV1ObservabilityCampaignsCampaignIDStatusGetRequestTypedDict(
    TypedDict
):
    campaign_id: str


class GetCampaignStatusByIDV1ObservabilityCampaignsCampaignIDStatusGetRequest(
    BaseModel
):
    campaign_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: f62d73a27faa

from __future__ import annotations
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class AudioURLTypedDict(TypedDict):
    r"""Audio URL.

    Attributes:
    url: The URL of the audio file.
    """

    url: str


class AudioURL(BaseModel):
    r"""Audio URL.

    Attributes:
    url: The URL of the audio file.
    """

    url: str



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 41ca596b44f8

from __future__ import annotations
from .connectortoollocale import ConnectorToolLocale, ConnectorToolLocaleTypedDict
from .executionconfig import ExecutionConfig, ExecutionConfigTypedDict
from .resourcevisibility import ResourceVisibility
from datetime import datetime
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import Any, Dict
from typing_extensions import NotRequired, TypedDict


class ConnectorToolTypedDict(TypedDict):
    id: str
    name: str
    description: str
    execution_config: Nullable[ExecutionConfigTypedDict]
    visibility: ResourceVisibility
    created_at: datetime
    modified_at: datetime
    system_prompt: NotRequired[Nullable[str]]
    locale: NotRequired[Nullable[ConnectorToolLocaleTypedDict]]
    jsonschema: NotRequired[Nullable[Dict[str, Any]]]
    active: NotRequired[Nullable[bool]]


class ConnectorTool(BaseModel):
    id: str

    name: str

    description: str

    execution_config: Nullable[ExecutionConfig]

    visibility: ResourceVisibility

    created_at: datetime

    modified_at: datetime

    system_prompt: OptionalNullable[str] = UNSET

    locale: OptionalNullable[ConnectorToolLocale] = UNSET

    jsonschema: OptionalNullable[Dict[str, Any]] = UNSET

    active: OptionalNullable[bool] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["system_prompt", "locale", "jsonschema", "active"])
        nullable_fields = set(
            ["system_prompt", "locale", "jsonschema", "execution_config", "active"]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 86c3b54272fd

from __future__ import annotations
from mistralai.client.types import UnrecognizedStr
from typing import Literal, Union


ToolTypes = Union[Literal["function",], UnrecognizedStr]
